makecmd is a package that converts Python files into command-line utilities that can be used on Unix and Linux-based operating systems. 
## Installation
```python
pip3 install makecmd

```

## Usage
```python 
makecmd <command> filename
```

